(function () {
  const client = ZAFClient.init();
  client.invoke("resize", { width: "100%", height: "150px" });

  client.get("deal.organization.name").then(function (data) {
    const orgName = data["deal.organization.name"];
    requestLeads(client, orgName);
  });
})();

function requestLeads(client, orgName) {
  const settings = {
    url:
      "/v2/leads/" +
      "?organization_name=" +
      encodeURIComponent(orgName) +
      "&status=new" +
      "&per_page=5",
    type: "GET",
    dataType: "json",
  };

  client.request(settings).then(
    function (data) {
      displayLeads(orgName, data);
    },
    function (response) {
      displayError(response);
    }
  );
}

function displayLeads(orgName, data) {
  const orgData = {
    orgName: orgName,
    leads: getLeads(data)
  };

  renderTemplate("org-template", orgData, "content");
}

function getLeads(data) {
  let leads = [];
  for (let lead of data.items) {
    leads.push({
      name: `${lead.data.first_name} ${lead.data.last_name}`,
      url: `https://app.futuresimple.com/leads/${lead.data.id}`,
    });
  }
  return leads;
}


function renderTemplate(templateId, dataObject, divId) {
  const source = document.getElementById(templateId).innerHTML;
  const template = Handlebars.compile(source);
  const compiledHtml = template(dataObject);
  document.getElementById(divId).innerHTML = compiledHtml;
}

function displayError(response) {
  const errorData = {
    'status': response.status,
    'statusText': response.statusText
  };

  renderTemplate("error-template", errorData, "content");
}